Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(594)

Unified Diff: pkg/analyzer/tool/summary/idl.dart

Issue 1540493003: Information about SDK libraries. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analyzer/lib/src/summary/format.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/tool/summary/idl.dart
diff --git a/pkg/analyzer/tool/summary/idl.dart b/pkg/analyzer/tool/summary/idl.dart
index 117dfe484b7da6266452194466bcc4280a8085bc..1506486fa1889bb7d1639328950e4d2592ebf486 100644
--- a/pkg/analyzer/tool/summary/idl.dart
+++ b/pkg/analyzer/tool/summary/idl.dart
@@ -98,7 +98,7 @@ class PrelinkedLibrary {
List<PrelinkedDependency> dependencies;
/**
* For each import in [UnlinkedLibrary.imports], an index into [dependencies]
* of the library being imported.
*
* TODO(paulberry): if [dependencies] is removed, this can be removed as
@@ -175,6 +175,40 @@ class PrelinkedUnit {
}
/**
+ * Information about SDK.
+ */
+@topLevel
+class SdkBundle {
+ /**
+ * Information for the libraries units constituting the SDK.
+ */
+ List<SdkBundleLibrary> libraries;
+}
+
+/**
+ * Information about a single library in SDK.
+ */
+class SdkBundleLibrary {
+ /**
+ * The URI of the library, including `dart:`, e.g. `dart:core`.
+ */
+ String uri;
+
+ /**
+ * Pre-linked information the library.
+ */
+ PrelinkedLibrary prelinked;
+
+ /**
+ * Unlinked information for the compilation units constituting the library.
+ * The zeroth entry in the list is the defining compilation unit; the
+ * remaining entries are the parts, in the order listed in the defining
+ * compilation unit's part declarations.
+ */
+ List<UnlinkedUnit> unlinkedUnits;
+}
+
+/**
* Unlinked summary information about a class declaration.
*/
class UnlinkedClass {
@@ -98,7 +98,7 @@ class PrelinkedLibrary {
List<PrelinkedDependency> dependencies;
/**
- * For each import in [UnlinkedLibrary.imports], an index into [dependencies]
+ * For each import in [UnlinkedUnit.imports], an index into [dependencies]
* of the library being imported.
*
« no previous file with comments | « pkg/analyzer/lib/src/summary/format.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698